@@ -22,7 +22,7 @@ import urllib.request
 from wasabi import color
 
 
-__version__ = "0.0.2"
+__version__ = "0.0.4"
 dir_path = os.path.dirname(os.path.realpath(__file__))
 
 
@@ -48,8 +48,9 @@ def check_aas_updates(jobType):
 	elif(jobType == 'postdoc'):
 		jobTypeId = 'PostDocFellow'
 	
-	source = urllib.request.urlopen('https://jobregister.aas.org/').read()
-	
+    req = urllib.request.Request('https://jobregister.aas.org', headers={'User-Agent': 'Mozilla/5.0'})
+	source = urllib.request.urlopen(req).read()
+
 	soup = bs.BeautifulSoup(source,'html.parser')
 	
 	jobs = soup.find(id=jobTypeId).nextSibling.find_all('td')
